@@ -3,7 +3,6 @@ Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
 import json
-import six
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
 
@@ -15,7 +14,7 @@ class AllowedValue(CloudFormationLintRule):
     id = 'W2030'
     shortdesc = 'Check if parameters have a valid value'
     description = 'Check if parameters have a valid value in case of an enumator. The Parameter\'s allowed values is based on the usages in property (Ref)'
-    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/master/docs/cfn-resource-specification.md#allowedvalue'
+    source_url = 'https://github.com/aws-cloudformation/cfn-python-lint/blob/main/docs/cfn-resource-specification.md#allowedvalue'
     tags = ['parameters', 'resources', 'property', 'allowed value']
 
     def initialize(self, cfn):
@@ -50,7 +49,7 @@ class AllowedValue(CloudFormationLintRule):
                 parameter_values = param.get('AllowedValues')
                 default_value = param.get('Default')
                 parameter_type = param.get('Type')
-                if isinstance(parameter_type, six.string_types):
+                if isinstance(parameter_type, str):
                     if ((not parameter_type.startswith('List<')) and
                             (not parameter_type.startswith('AWS::SSM::Parameter::Value<')) and
                             parameter_type not in ['CommaDelimitedList', 'List<String>']):
